<?php
// $Id: toolbar.banners.html.php,v 1.9 2003/10/06 23:07:05 eddieajau Exp $
/**
* Banner toolbar HTML
* @package Mambo Open Source
* @Copyright (C) 2000 - 2003 Miro International Pty Ltd
* @ All rights reserved
* @ Mambo Open Source is Free Software
* @ Released under GNU/GPL License : http://www.gnu.org/copyleft/gpl.html
* @version $Revision: 1.9 $
**/

// ensure this file is being included by a parent file
defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );

class menubanners {
/**
* Draws the menu for a New banner
*/
	function NEW_MENU()
	{
		mosMenuBar::startTable();
		mosMenuBar::media_manager( "banners" );
		mosMenuBar::divider();
		mosMenuBar::save();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
/**
* Draws the menu for to Edit a banner
*/
	function EDIT_MENU()
	{
		mosMenuBar::startTable();
		mosMenuBar::media_manager( "banners" );
		mosMenuBar::divider();
		mosMenuBar::save();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
}

class menubannerClient {
/**
* Draws the menu for a New client
*/
	function NEW_MENU()
	{
		mosMenuBar::startTable();
		mosMenuBar::save( 'saveclient' );
		mosMenuBar::cancel( 'cancelclient' );
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
/**
* Draws the menu for to Edit a client
*/
	function EDIT_MENU()
	{
		mosMenuBar::startTable();
		mosMenuBar::save( 'saveclient' );
		mosMenuBar::cancel( 'cancelclient' );
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
/**
* Draws the default menu
*/
	function DEFAULT_MENU()
	{
		mosMenuBar::startTable();
		mosMenuBar::addNew( 'newclient' );
		mosMenuBar::editList( 'editclient' );
		mosMenuBar::deleteList( '', 'removeclients' );
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
}
?>